@@ -1,10 +1,11 @@
 import string, random
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.auth.models import User
 from hunger.utils import setting
 from hunger.signals import invite_sent
 
+User = setting('AUTH_USER_MODEL')
+
 
 class Invitation(models.Model):
     user = models.ForeignKey(User, blank=True, null=True)
